@@ -16,19 +16,46 @@ sampleN.TOST(CV = 0.30, details = FALSE, print = FALSE)[["Sample size"]]
 ## ----example1c----------------------------------------------------------------
 power.TOST(CV = 0.30, n = 39)
 
+## ----example1vect-------------------------------------------------------------
+sampleN.TOST.vectorized <- function(CVs, theta0s, ...) {
+  n <- power <- matrix(ncol = length(CVs), nrow = length(theta0s))
+  for (i in seq_along(theta0s)) {
+    for (j in seq_along(CVs)) {
+      tmp         <- sampleN.TOST(CV = CVs[j], theta0 = theta0s[i], ...)
+      n[i, j]     <- tmp[["Sample size"]]
+      power[i, j] <- tmp[["Achieved power"]]
+    }
+  }
+  DecPlaces <- function(x) match(TRUE, round(x, 1:15) == x)
+  fmt.col <- paste0("CV %.",    max(sapply(CVs, FUN = DecPlaces),
+                                    na.rm = TRUE), "f")
+  fmt.row <- paste0("theta %.", max(sapply(theta0s, FUN = DecPlaces),
+                                    na.rm = TRUE), "f")
+  colnames(power) <- colnames(n) <- sprintf(fmt.col, CVs)
+  rownames(power) <- rownames(n) <- sprintf(fmt.row, theta0s)
+  res <- list(n = n, power = power)
+  return(res)
+}
+CVs     <- seq(0.20, 0.40, 0.05)
+theta0s <- seq(0.90, 0.95, 0.01)
+x       <- sampleN.TOST.vectorized(CV = CVs, theta0 = theta0s,
+                                   details = FALSE, print = FALSE)
+cat("Sample size\n"); print(x$n); cat("Achieved power\n"); print(signif(x$power, digits = 5))
+
 ## ----example1d----------------------------------------------------------------
 designs <- c("2x2x2", "2x2x3", "2x3x3", "2x2x4")
 # data.frame of results
-res <- data.frame(design = designs, n = NA, power = NA, n.do = NA,
-                  power.do = NA,
+res <- data.frame(design = designs, n = NA_integer_,
+                  power = NA_real_, n.do = NA_integer_,
+                  power.do = NA_real_,
                   stringsAsFactors = FALSE) # this line for R <4.0.0
 for (i in 1:4) {
-  # print = FALSE and details = FALSE suppress output to the console
+  # print = FALSE suppresses output to the console
   # we are only interested in columns 7-8
   # let's also calculate power for one dropout
   res[i, 2:3] <- sampleN.TOST(CV = 0.30, design = res$design[i],
-                              print = FALSE, details = FALSE)[7:8]
-  res[i, 4]   <-  res[i, 2] - 1
+                              print = FALSE)[7:8]
+  res[i, 4]   <- res[i, 2] - 1
   res[i, 5]   <- suppressMessages(
                     power.TOST(CV = 0.30, design = res$design[i],
                                n = res[i, 4]))
@@ -37,18 +64,18 @@ print(res, row.names = FALSE)
 
 ## ----example1e, echo = FALSE--------------------------------------------------
 designs <- c("2x2x2", "2x2x3", "2x3x3", "2x2x4")
-res <- data.frame(design = rep(NA, 4), name = NA, n = NA, formula = NA,
-                  df = NA, t.value = NA,
+res <- data.frame(design = rep(NA_character_, 4), name = NA_character_,
+                  n = NA_integer_, formula = NA_character_,
+                  df = NA_real_, t.value = NA_real_,
                   stringsAsFactors = FALSE) # this line for R <4.0.0
-res[, c(2:1, 4)] <- known.designs()[which(known.designs()[, 2] %in% designs),
-                                    c(9, 2:3)]
+res[, c(2:1, 4)] <- known.designs()[which(known.designs()[, 2] %in% designs), c(9, 2:3)]
 for (i in 1:4) {
   res$n[i]  <- sampleN.TOST(CV = 0.30, design = res$design[i],
-                            print = FALSE, details = FALSE)[["Sample size"]]
-  e         <- parse(text=res[i, 4], srcfile=NULL)
+                            print = FALSE)[["Sample size"]]
+  e         <- parse(text = res[i, 4], srcfile = NULL)
   n         <- res$n[i]
   res[i, 5] <- eval(e)
-  res$t.value[i] <- signif(qt(1-0.05, df = res[i, 5]), 4)
+  res$t.value[i] <- signif(qt(1 - 0.05, df = res[i, 5]), 4)
 }
 res <- res[with(res, order(-n, design)), ]
 print(res, row.names = FALSE)
@@ -57,7 +84,7 @@ print(res, row.names = FALSE)
 grouping <- function(capacity, n) {
   # split sample size into >=2 groups based on capacity
   if (n <= capacity) { # make equal groups
-    ngrp <- rep(ceiling(n/2), 2)
+    ngrp <- rep(ceiling(n / 2), 2)
   } else {             # at least one = capacity
     ngrp    <- rep(0, ceiling(n / capacity))
     grps    <- length(ngrp)
@@ -75,7 +102,9 @@ grouping <- function(capacity, n) {
 }
 CV        <- 0.30
 capacity  <- 24 # clinical capacity
-res       <- data.frame(n = NA, grps = NA, n.grp = NA, m.1 = NA, m.2 = NA)
+res       <- data.frame(n = NA_integer_, grps = NA_integer_,
+                        n.grp = NA_integer_,
+                        m.1 = NA_real_, m.2 = NA_real_)
 x         <- sampleN.TOST(CV = CV, print = FALSE, details = FALSE)
 res$n     <- x[["Sample size"]]
 res$m.1   <- x[["Achieved power"]]
@@ -85,7 +114,7 @@ ngrp      <- x[["ngrp"]]
 res$n.grp <- paste(ngrp, collapse = "|")
 res$m.2   <- power.TOST.sds(CV = CV, n = res$n, grps = res$grps,
                             ngrp = ngrp, gmodel = 2, progress = FALSE)
-res$loss <- 100*(res$m.2 - res$m.1)/res$m.1
+res$loss <- 100*(res$m.2 - res$m.1) / res$m.1
 names(res)[2:6] <- c("groups", "n/group", "pooled model",
                      "group model", "loss (%)")
 res[1, 4:6] <- sprintf("%6.4f", res[1, 4:6])
@@ -132,17 +161,17 @@ expsampleN.TOST(CV = 0.20, theta0 = 0.92, prior.type = "both",
 CV  <- 0.214
 res <- data.frame(target = c(rep(0.8, 5), rep(0.9, 5)),
                   theta0 = rep(c(1, seq(0.95, 0.92, -0.01)), 2),
-                  n.1 = NA, power = NA,
+                  n.1 = NA_integer_, power = NA_real_,
                   sigma.u = rep(c(0.0005, seq(0.05, 0.08, 0.01)), 2),
-                  n.2 = NA, assurance = NA)
+                  n.2 = NA_integer_, assurance = NA_real_)
 for (i in 1:nrow(res)) {
   res[i, 3:4] <- sampleN.TOST(CV = CV, targetpower = res$target[i],
-                              theta0 = res$theta0[i], details = FALSE,
-                              print = FALSE)[7:8]
+                              theta0 = res$theta0[i], print = FALSE)[7:8]
   res[i, 6:7] <- expsampleN.TOST(CV = CV, targetpower = res$target[i],
-                                 theta0 = 1, prior.type = "theta0",
+                                 theta0 = 1, # mandatory!
+                                 prior.type = "theta0",
                                  prior.parm = list(sem = res$sigma.u[i]),
-                                 details = FALSE, print = FALSE)[9:10]
+                                 print = FALSE)[9:10]
 }
 res                 <- signif(res, 3)
 res[, 5]            <- sprintf("%.2f", res[, 5])
@@ -162,29 +191,31 @@ sampleN.TOST(CV = SD.resid, theta0 = theta0, theta1 = theta1,
 ## ----example4b----------------------------------------------------------------
 known    <- known.designs()[, c(2, 6)]           # extract relevant information
 bk       <- known[known$design == planned, "bk"] # retrieve design constant
-cat(paste0("The design constant for design \"", planned, "\" is ", bk, "\n"))
+txt      <- paste0("The design constant for design \"",
+                   planned, "\" is ", bk)
 SD.delta <-  28                                  # standard deviation of the difference
 SD.resid <-  SD.delta / sqrt(bk)                 # convert to residual SD
-sampleN.TOST(CV = SD.resid, theta0 = theta0, theta1 = theta1,
-             theta2 = theta2, logscale = logscale, design = planned)
+cat(txt); sampleN.TOST(CV = SD.resid, theta0 = theta0,
+                       theta1 = theta1, theta2 = theta2,
+                       logscale = logscale, design = planned)
 
 ## ----higher_order1------------------------------------------------------------
 CV  <- 0.20
-res <- data.frame(design = c("3x6x3", "2x2x2"), n = NA, power = NA,
-                  stringsAsFactors = FALSE)
+res <- data.frame(design = c("3x6x3", "2x2x2"), n = NA_integer_,
+                  power = NA_real_, stringsAsFactors = FALSE)
 for (i in 1:2) {
   res[i, 2:3] <- sampleN.TOST(CV = CV, design = res$design[i],
-                              details = FALSE, print = FALSE)[7:8]
+                              print = FALSE)[7:8]
 }
 print(res, row.names = FALSE)
 
 ## ----higher_order2------------------------------------------------------------
 CV  <- 0.20
-res <- data.frame(design = c("4x4", "2x2x2"), n = NA, power = NA,
-                  stringsAsFactors = FALSE)
+res <- data.frame(design = c("4x4", "2x2x2"), n = NA_integer_,
+                  power = NA_real_, stringsAsFactors = FALSE)
 for (i in 1:2) {
   res[i, 2:3] <- sampleN.TOST(CV = CV, design = res$design[i],
-                              details = FALSE, print = FALSE)[7:8]
+                              print = FALSE)[7:8]
 }
 print(res, row.names = FALSE)
 
@@ -197,7 +228,7 @@ power.TOST(CV = 0.25, theta0 = 0.90, n = c(13, 12)) # observed values
 
 ## ----power3-------------------------------------------------------------------
 power.TOST(CV = 0.20, theta0 = 0.92, n = 28)     # assumed in planning
-power.TOST(CV = 0.25, theta0 = 1, n = c(13, 12)) # observed but wrong T/R-ratio
+power.TOST(CV = 0.25, theta0 = 1, n = c(13, 12)) # observed CV but wrong T/R-ratio
 
 ## ----pooling------------------------------------------------------------------
 CVs <- ("  CV |  n | design | study
@@ -218,18 +249,20 @@ balance <- function(x, y) {
 }
 do        <- 0.15 # anticipated dropout-rate 15%
 seqs      <- 3
-n         <- seq(12, 96, 12)
+n         <- seq(12L, 96L, 12L)
 res       <- data.frame(n = n,
                         adj1 = balance(n / (1 - do), seqs), # correct
-                        elig1 = NA, diff1 = NA,
+                        elig1 = NA_integer_, diff1 = NA_integer_,
                         adj2 = balance(n * (1 + do), seqs), # wrong
-                        elig2 = NA, diff2 = NA)
+                        elig2 = NA_integer_, diff2 = NA_integer_)
 res$elig1 <- floor(res$adj1 * (1 - do))
 res$diff1 <- sprintf("%+i", res$elig1 - n)
 res$elig2 <- floor(res$adj2 * (1 - do))
 res$diff2 <- sprintf("%+i", res$elig2 - n)
 invisible(
-  ifelse(res$elig1 - n >=0, res$optim <- res$elig1, res$optim <- res$elig2))
+  ifelse(res$elig1 - n >=0,
+         res$optim <- res$elig1,
+         res$optim <- res$elig2))
 res$diff  <- sprintf("%+i", res$optim - n)
 names(res)[c(2, 5)] <- c("n'1", "n'2")
 res$diff1[which(res$diff1 == "+0")] <- "\u00B10"
@@ -242,21 +275,25 @@ CVfromCI(lower = 0.8323, upper = 1.0392, design = "2x2x4", n = 26)
 
 ## ----lit2---------------------------------------------------------------------
 n      <- 26
-CV.est <- CVfromCI(lower = 0.8323, upper = 1.0392, design = "2x2x4", n = 26)
-n.est  <- sampleN.TOST(CV = CV.est, design = "2x2x4", print = FALSE,
-                       details = FALSE)[["Sample size"]]
+CV.est <- CVfromCI(lower = 0.8323, upper = 1.0392,
+                   design = "2x2x4", n = 26)
+n.est  <- sampleN.TOST(CV = CV.est, design = "2x2x4",
+                       print = FALSE)[["Sample size"]]
 n1     <- balance(seq(n, 18, -1), 2) / 2
 n2     <- n - n1
 nseqs  <- unique(data.frame(n1 = n1, n2 = n2, n = n))
-res    <- data.frame(n1 = nseqs$n1, n2 = nseqs$n2, CV.true = NA,
-                     CV.est = CV.est, n.true = NA, n.est = n.est)
+res    <- data.frame(n1 = nseqs$n1, n2 = nseqs$n2,
+                     CV.true = NA_real_,
+                     CV.est = CV.est, n.true = NA_integer_,
+                     n.est = n.est)
 for (i in 1:nrow(res)) {
-  res$CV.true[i] <- CVfromCI(lower = 0.8323, upper = 1.0392, design = "2x2x4",
+  res$CV.true[i] <- CVfromCI(lower = 0.8323, upper = 1.0392,
+                             design = "2x2x4",
                              n = c(res$n1[i], res$n2[i]))
   res$n.true[i]  <- sampleN.TOST(CV = res$CV.true[i], design = "2x2x4",
-                                 print = FALSE, details = FALSE)[["Sample size"]]
+                                 print = FALSE)[["Sample size"]]
   res$n.est[i]   <- sampleN.TOST(CV = CV.est, design = "2x2x4",
-                                 print = FALSE, details = FALSE)[["Sample size"]]
+                                 print = FALSE)[["Sample size"]]
 }
 print(signif(res, 5), row.names = FALSE)
 
@@ -266,14 +303,14 @@ d    <- 0.05 # delta 5%, direction unknown
 n    <- sampleN.TOST(CV = CV, theta0 = 1 - d, print = FALSE,
                      details = FALSE)[["Sample size"]]
 res1 <- data.frame(CV = CV, theta0 = c(1 - d, 1 / (1 - d)),
-                   n = n, power = NA)
+                   n = n, power = NA_real_)
 for (i in 1:nrow(res1)) {
   res1$power[i] <- power.TOST(CV = CV, theta0 = res1$theta0[i], n = n)
 }
-n    <- sampleN.TOST(CV = CV, theta0 = 1 + d, print = FALSE,
-                     details = FALSE)[["Sample size"]]
+n    <- sampleN.TOST(CV = CV, theta0 = 1 + d,
+                     print = FALSE)[["Sample size"]]
 res2 <- data.frame(CV = CV, theta0 = c(1 + d, 1 / (1 + d)),
-                   n = n, power = NA)
+                   n = n, power = NA_real_)
 for (i in 1:nrow(res1)) {
   res2$power[i] <- power.TOST(CV = CV, theta0 = res2$theta0[i], n = n)
 }
